@@ -47,7 +47,6 @@ class Patch:
         self.__prev_release_s = self.__hop_cls.get_release_s(self.__prev_release)
         self.__next_release = self.__hop_cls.get_next_release()
         self.__next_release_s = self.__next_release and self.__hop_cls.get_release_s(self.__next_release)
-        # print('XXX update release', self.__prev_release_s, self.__curr_release_s, self.__next_release_s)
 
 
     @property
@@ -197,8 +196,7 @@ class Patch:
                 f"Oops! there is already a dump for the {self.__hop_cls.last_release_s} release.\n")
             sys.stderr.write(f"Please use the --force option if you realy want to proceed.\n")
             sys.exit(1)
-        err = subprocess.run(['pg_dump', self.dbname, '-f', svg_file], check=True, stderr=subprocess.PIPE)
-        print(err)
+        _ = subprocess.run(['pg_dump', self.dbname, '-f', svg_file], check=True, stderr=subprocess.PIPE)
 
     def __patch(self, commit=None, force=False):
         "Applies the patch and insert the information in the half_orm_meta.hop_release table"
@@ -267,7 +265,7 @@ class Patch:
                 with subprocess.Popen(file_.path, shell=True) as sub:
                     sub.wait()
 
-        update_modules(self.model, self.package_name)
+        update_modules(self.model, self.package_name, self.__hop_cls.release_s)
         self.__register()
 
     # def apply_issue(self, issue, commit=None, bundled_issue=None):
@@ -298,13 +296,13 @@ class Patch:
         print(f'PREPARING: {new_release_s}')
         patch_path = 'Patches/{major}/{minor}/{patch}'.format(**next)
         if not os.path.exists(patch_path):
-            changelog_msg = input('CHANGELOG message (leave empty to abort): ')
+            changelog_msg = input('CHANGELOG message - will be prepended by (version_number) - (leave empty to abort): ')
             if not changelog_msg:
                 print('Aborting')
                 return
             os.makedirs(patch_path)
             with open(f'{patch_path}/CHANGELOG.md', 'w', encoding='utf-8') as changelog:
-                changelog.write(changelog_msg)
+                changelog.write('({}) {}'.format(new_release_s, changelog_msg))
         self.__hgit.set_branch(new_release_s)
         print(f'You can now add your patch scripts (*.py, *.sql) in {patch_path}. See Patches/README.')
 
